@@ -11,25 +11,35 @@
 }
 
 
+
 #' @export
 as.array.keras.src.backend.common.variables.KerasVariable <- function(x, ...) {
   as_r_value(keras$ops$convert_to_numpy(x))
 }
+#' @export
+as.array.keras.src.backend.Variable <- as.array.keras.src.backend.common.variables.KerasVariable
+
 
 #' @export
 as.numeric.keras.src.backend.common.variables.KerasVariable <- function(x, ...) {
   as.numeric(as_r_value(keras$ops$convert_to_numpy(x)))
 }
+#' @export
+as.numeric.keras.src.backend.Variable <- as.numeric.keras.src.backend.common.variables.KerasVariable
 
 #' @export
 as.double.keras.src.backend.common.variables.KerasVariable <- function(x, ...) {
   as.double(as_r_value(keras$ops$convert_to_numpy(x)))
 }
+#' @export
+as.double.keras.src.backend.Variable <- as.double.keras.src.backend.common.variables.KerasVariable
 
 #' @export
 as.integer.keras.src.backend.common.variables.KerasVariable <- function(x, ...) {
   as.integer(as_r_value(keras$ops$convert_to_numpy(x)))
 }
+#' @export
+as.integer.keras.src.backend.Variable <- as.integer.keras.src.backend.common.variables.KerasVariable
 
 
 #' @exportS3Method base::all.equal
@@ -41,6 +51,7 @@ function(target, current, ...) {
     current <- as_r_value(current$numpy())
   all.equal(target, current, ...)
 }
+all.equal.keras.src.backend.Variable <- all.equal.keras.src.backend.common.variables.KerasVariable
 
 
 ## This method isn't the best semantic match for all.equal(), but identical()
@@ -56,6 +67,9 @@ function(target, current, ...) {
   inherits(current, "keras.src.backend.common.keras_tensor.KerasTensor") &&
   py_id(target) == py_id(current)
 }
+#' @exportS3Method base::all.equal
+all.equal.keras.src.backend.Tensor <- all.equal.keras.src.backend.common.keras_tensor.KerasTensor
+
 
 ## Conditionally export these py_to_r methods, if tensorflow hasn't already exported them.
 ## We do this to keep keras3 and tensorflow decoupled, but to avoid
@@ -73,3 +87,19 @@ py_to_r__keras.src.utils.tracking.TrackedList <- function(x) import("builtins")$
 
 py_to_r__keras.src.utils.tracking.TrackedSet <- function(x) import("builtins")$list(x)
 
+#  @rawNamespace S3method(as.array,   keras.src.backend.Variable)
+#  @rawNamespace S3method(as.numeric, keras.src.backend.Variable)
+#  @rawNamespace S3method(as.double,  keras.src.backend.Variable)
+#  @rawNamespace S3method(as.integer, keras.src.backend.Variable)
+#  @rawNamespace S3method(all.equal,  keras.src.backend.Variable)
+#  @rawNamespace S3method(`+`,        keras.src.backend.Variable)
+#  @rawNamespace S3method(`==`,       keras.src.backend.Variable)
+# for(generic in c("==", "+", "as.array", "as.numeric", "as.double", "as.integer", "all.equal")) {
+#   for (cls in c("keras.src.backend.Variable", "keras.src.backend.Tensor"))
+#     assign(
+#       sprintf("%s.%s", generic, cls),
+#       get(sprintf("%s.keras.src.backend.common.keras_tensor.KerasTensor", generic)))
+# }
+# rm(list = c("generic", "cls"))
+
+
